#!/usr/bin/env bash

set -e

DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

BUILD_DOCKERFILE=${BUILD_DOCKERFILE-Dockerfile}
CLEAN_IMAGE_NAME=${CLEAN_IMAGE_NAME:-psc-access-rbac-clean}

LOCAL_RUN_FLAG=local-rbac-clean

GITLAB_TOKEN_RBAC_CLEAN=${GITLAB_TOKEN_RBAC_CLEAN:-$LOCAL_RUN_FLAG}
CI_COMMIT_REF_NAME=${CI_COMMIT_REF_NAME:-$LOCAL_RUN_FLAG}

echo "Using branch: " $CI_COMMIT_REF_NAME

docker build --build-arg "GITLAB_TOKEN_RBAC_CLEAN=${GITLAB_TOKEN_RBAC_CLEAN}" --build-arg "CI_COMMIT_REF_NAME=${CI_COMMIT_REF_NAME}" \
    --build-arg "LOCAL_RUN_FLAG=${LOCAL_RUN_FLAG}" -t ${CLEAN_IMAGE_NAME}:latest -f ${BUILD_DOCKERFILE} ${DIR}

# Either run locally or within pipeline
if [ "$GITLAB_TOKEN_RBAC_CLEAN" == "$LOCAL_RUN_FLAG" ] && [ "$CI_COMMIT_REF_NAME" == "$LOCAL_RUN_FLAG" ]; then
    echo "Running locally..."
    docker run --rm -v $(pwd)/secops:/cleaned-files ${CLEAN_IMAGE_NAME}:latest sh -c "python clean/rbac-clean-summoner.py && cp -r secops/* /cleaned-files"
else
    echo "Running in pipeline..."
    docker run --rm ${CLEAN_IMAGE_NAME}:latest python cleaner/rbac-clean-summoner.py
fi
