import json
from re import search
from os import listdir
import logging
import urllib3

fields_to_clean = ['version', 'created_at', 'created_by', 'updated_at', 'updated_by']
rbac_type = ['roles', 'subroles', 'permissions']
rbac_type_fields_dict = {
                            'roles' : ['permissions', 'subroles', 'overrides'],
                            'subroles' : ['permissions'],
                            'permissions' : []
                                                    }

urllib3.disable_warnings()
logger = logging.getLogger("rbac-sanitizer")
logger.setLevel(logging.INFO)
formatter = logging.Formatter("%(asctime)s %(levelname)s - %(message)s")
handler_console = logging.StreamHandler()
handler_console.setFormatter(formatter)
logger.addHandler(handler_console)

def sanitize_all_and_save():
    '''
        Navigates our files structure for RBAC files and calls the sanitizer
    '''
    json_file_paths = ['roles', 'permissions', 'subroles']
    for json_file_path in json_file_paths:
        rbac_file_path = 'live/' + json_file_path + '/'
        # Filter out non-json files
        files = [rbac_file_path + file for file in listdir(rbac_file_path) if file.endswith(".json")]
        for file_path in files:
            with open(file_path, 'r+') as rbac_file:
                rbac_entity = json.load(rbac_file)

                sanitize(file_path, rbac_entity)

                # Reset file position to the beginning.
                rbac_file.seek(0)

                # Sort and dump json
                json.dump(rbac_entity, rbac_file, indent=4, sort_keys=True)
                rbac_file.truncate()
                logger.info("Sanitized rbac json file at %s" % file_path)

def sanitize(file_name, data):
    '''
        Remove unwanted fields from JSON defined in the fields_to_clean variable
    '''
    parsed_rbac_type = get_rbac_type(file_name)
    rbac_type_fields = rbac_type_fields_dict[parsed_rbac_type]

    # Clean the top level
    if (parsed_rbac_type == 'roles'):
        clean(data['role_definition'])
    elif (parsed_rbac_type == 'subroles'):
        clean(data)
    elif (parsed_rbac_type == 'permissions'):
        clean(data)
    else:
        raise Exception("Undefined rbac type")

    # Loop through any list of permissions, subroles, or overrides to clean
    if parsed_rbac_type == 'roles' or parsed_rbac_type == 'subroles':
        for field_list in rbac_type_fields:
            for field in data[field_list]:
                clean(field)
    return data

def clean(rbac_entity):
    for field in fields_to_clean:
        rbac_entity.pop(field, None)

def get_rbac_type(path):
    m = search('secops\/(.+?)\/(.*)', path)
    if m:
        found = m.group(1)
        if found in rbac_type:
            return found
    else:
        raise Exception("Could not parse rbac type: roles, permissions, or subroles")

